==> OpenInteract-1.99_03.tar.gz: base_template-3.05/OpenInteract2/Action/SiteTemplate.pm <==
package OpenInteract2::Action::SiteTemplate;

# $Id: SiteTemplate.pm,v 1.9 2003/08/27 15:50:17 lachoy Exp $

use strict;
use base qw( OpenInteract2::Action );
use Log::Log4perl            qw( get_logger );
use OpenInteract2::Constants qw( :log );
use OpenInteract2::Context   qw( CTX );
use SPOPS::Secure            qw( SEC_LEVEL_WRITE );

$OpenInteract2::Action::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);

sub list {
    my ( $self ) = @_;
    my $log = get_logger( LOG_APP );

    $log->is_info &&
        $log->info( "Listing templates in system" );
    my $website_dir = CTX->server_config->{dir}{website};
    my $packages = CTX->repository->fetch_all_packages();
    my $tmpl_class = CTX->lookup_class( 'template' );
    my %templates = ();
    foreach my $pkg ( @{ $packages } ) {
        eval {
            $templates{ $pkg->name } =
                         $tmpl_class->fetch_by_package( $pkg->name );
        };
        if ( $@ ) {
            my $msg = "Failed to fetch templates in " . $pkg->name . ": $@";
            $log->error( $msg );
            $self->param_add( error_msg => $msg );
        }
    }
    eval {
        $templates{ '' } = $tmpl_class->fetch_by_package( '' )
    };
    if ( $@ ) {
        my $msg = "Failed to get global templates: $@";
        $log->error( $msg );
        $self->param_add( error_msg => $msg );
    }
    return $self->generate_content(
                    { package_templates => \%templates },
                    { name => 'base_template::template_list' } );
}

sub _set_package_info {
    my ( $self, $template_params ) = @_;
    my $packages = CTX->packages;
    for ( @{ $packages } ) {
        push @{ $template_params->{package_list} }, $_->{name};
        push @{ $template_params->{package_labels} }, $_->{name};
    }
}

sub display_form {
    my ( $self ) = @_;
    my $log = get_logger( LOG_APP );

    my %params = ( package_list   => [ '' ],
                   package_labels => [ 'Global Templates' ] );
    $self->_set_package_info( \%params );

    my $tmpl_class = CTX->lookup_class( 'template' );
    my $request = CTX->request;
    my $template = $self->param( 'template' );
    unless ( $template ) {
        my $package = $request->param( 'package' );
        my $name    = $request->param( 'name' );
        if ( $name ) {
            my $fq_name = $tmpl_class->create_name( $package, $name );
            $template = eval { $tmpl_class->fetch( $fq_name ) };
            if ( $@ || ! $template ) {
                my $error = $@ || 'not found';
                $self->param_add(
                    error_msg => "Failed to fetch template [$fq_name]: $error" );
                return $self->execute({ task => 'list' });
            }
        }
    }
    $log->is_info &&
        $log->info( "Display update form for: ", $template->create_name );
    $params{tmpl} = $template;
    return $self->generate_content(
                    \%params,
                    { name => 'base_template::template_form' } );
}

sub display_add {
    my ( $self ) = @_;
    my $tmpl_class = CTX->lookup_class( 'template' );

    # We might have one leftover from a failed 'add'...
    my $template = $self->param( 'template' ) || $tmpl_class->new;

    my %params = ( tmpl           => $template,
                   package_list   => [ '' ],
                   package_labels => [ 'Global Templates' ] );
    $self->_set_package_info( \%params );
    return $self->generate_content(
                    \%params,
                    { name => 'base_template::template_form' } );
}

sub update {
    my ( $self ) = @_;
    my $log = get_logger( LOG_APP );

    $log->is_info &&
        $log->info( "Updating existing template" );
    $self->response->return_url(
        OpenInteract2::URL->create_from_action( 'template' ) );

    my $request = CTX->request;
    my $package = $request->param( 'package_original' );
    my $name    = $request->param( 'name_original' );

    my $tmpl_class = CTX->lookup_class( 'template' );
    my $fq_name = $tmpl_class->create_name( $package, $name );
    my $template = eval { $tmpl_class->fetch( $fq_name ) };
    if ( $@ or ! $template ) {
        my $error = $@ || 'not found';
        $self->param_add(
            error_msg => "Failed to fetch template [$fq_name]: $error" );
        return $self->execute({ task => 'list' });
    }
    $template->package( $request->param( 'package' ) );
    $template->name( $request->param( 'name' ) );
    $template->set_contents( $request->param( 'contents' ) );
    eval { $template->save };
    if ( $@ ) {
        $self->param_add( error_msg => "Failed to save template: $@" );
        $self->param( template => $template );
        return $self->execute({ task => 'display_form' });
    }
    else {
        my $new_name = $template->create_name;
        $self->param_add( status_msg => "Template $new_name saved ok" );
        return $self->execute({ task => 'list' });
    }
}


sub add {
    my ( $self ) = @_;
    my $log = get_logger( LOG_APP );

    $log->is_info &&
        $log->info( "Adding new template" );

    $self->response->return_url(
        OpenInteract2::URL->create_from_action( 'template' ) );

    my $request = CTX->request;

    my $tmpl_class = CTX->lookup_class( 'template' );
    my $template = $tmpl_class->new;

    my $package = $request->param( 'package' );
    my $name    = $request->param( 'name' );

    $template->package( $package );
    $template->name( $name );
    $template->set_contents( $request->param( 'contents' ) );
    $self->param( template => $template );

    my $fq_name = $tmpl_class->create_name( $package, $name );
    my $existing_template = eval { $tmpl_class->fetch( $fq_name ) };
    if ( $existing_template ) {
        $self->param_add(
            error_msg => "Template [$fq_name] already exists, cannot create" );
        return $self->execute({ task => 'display_add' });
    }

    eval { $template->save };
    if ( $@ ) {
        $self->param_add( error_msg => "Failed to create template: $@" );
        return $self->execute({ task => 'display_add' });
    }
    else {
        $self->param_add( status_msg => "Template $fq_name saved ok" );
        return $self->execute({ task => 'list' });
    }
}


sub remove {
    my ( $self ) = @_;
    my $log = get_logger( LOG_APP );

    $log->is_info &&
        $log->info( "Removing existing template" );

    my $request = CTX->request;
    my $template = $self->param( 'template' );
    my ( $fq_name );
    if ( $template ) {
        $fq_name = $template->create_name;
    }
    else {
        my $package = $request->param( 'package' );
        my $name    = $request->param( 'name' );
        my $tmpl_class = CTX->lookup_class( 'template' );
        $fq_name = $tmpl_class->create_name( $package, $name );
        $template = eval { $tmpl_class->fetch( $fq_name ) };
        if ( $@ ) {
            $self->param_add(
                error_msg => "Cannot fetch template [$fq_name]: $@" );
            return $self->execute({ task => 'list' });
        }
    }
    if ( $template ) {
        eval { $template->remove };
        if ( $@ ) {
            $self->param_add(
                error_msg => "Error removing template $fq_name: $@" );
        }
        else {
            $self->param_add(
                status_msg => "Template $fq_name removed ok" );
        }
    }
    else {
        $self->param_add(
            error_msg => "Template [$fq_name] does not seem to exist" );
    }
    return $self->execute({ task => 'list' });
}

1;

==> OpenInteract-1.99_04.tar.gz: base_template-3.11/OpenInteract2/Action/SiteTemplate.pm <==
package OpenInteract2::Action::SiteTemplate;

# $Id: SiteTemplate.pm,v 1.13 2004/05/22 15:04:36 lachoy Exp $

use strict;
use base qw( OpenInteract2::Action );
use Log::Log4perl            qw( get_logger );
use OpenInteract2::Constants qw( :log );
use OpenInteract2::Context   qw( CTX );
use SPOPS::Secure            qw( SEC_LEVEL_WRITE );

$OpenInteract2::Action::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);

my ( $log );

sub list {
    my ( $self ) = @_;
    $log ||= get_logger( LOG_APP );

    $log->is_info &&
        $log->info( "Listing templates in system" );
    my $website_dir = CTX->lookup_directory( 'website' );
    my $packages = CTX->repository->fetch_all_packages();
    my $tmpl_class = CTX->lookup_class( 'template' );
    my %templates = ();
    foreach my $pkg ( @{ $packages } ) {
        eval {
            $templates{ $pkg->name } =
                         $tmpl_class->fetch_by_package( $pkg->name );
        };
        if ( $@ ) {
            my $msg = "Failed to fetch templates in " . $pkg->name . ": $@";
            $log->error( $msg );
            $self->param_add( error_msg => $msg );
        }
    }

    # This looks weird but we're just finding the global templates
    eval {
        $templates{ '' } = $tmpl_class->fetch_by_package( '' )
    };
    if ( $@ ) {
        my $msg = "Failed to get global templates: $@";
        $log->error( $msg );
        $self->param_add( error_msg => $msg );
    }
    return $self->generate_content(
                    { package_templates => \%templates },
                    { name => 'base_template::template_list' } );
}

sub _set_package_info {
    my ( $self, $template_params ) = @_;
    my $packages = CTX->packages;
    for ( @{ $packages } ) {
        push @{ $template_params->{package_list} }, $_->{name};
        push @{ $template_params->{package_labels} }, $_->{name};
    }
}

sub display_form {
    my ( $self ) = @_;
    $log ||= get_logger( LOG_APP );

    my %params = ( package_list   => [ '' ],
                   package_labels => [ 'Global Templates' ] );
    $self->_set_package_info( \%params );

    my $tmpl_class = CTX->lookup_class( 'template' );
    my $request = CTX->request;
    my $template = $self->param( 'template' );
    unless ( $template ) {
        my $package = $request->param( 'package' );
        my $name    = $request->param( 'name' );
        if ( $name ) {
            my $fq_name = $tmpl_class->create_name( $package, $name );
            $template = eval { $tmpl_class->fetch( $fq_name ) };
            if ( $@ || ! $template ) {
                my $error = $@ || 'not found';
                $self->param_add(
                    error_msg => "Failed to fetch template [$fq_name]: $error" );
                return $self->execute({ task => 'list' });
            }
        }
    }
    $log->is_info &&
        $log->info( "Display update form for: ", $template->create_name );
    $params{tmpl} = $template;
    return $self->generate_content(
                    \%params,
                    { name => 'base_template::template_form' } );
}

sub display_add {
    my ( $self ) = @_;
    my $tmpl_class = CTX->lookup_class( 'template' );

    # We might have one leftover from a failed 'add'...
    my $template = $self->param( 'template' ) || $tmpl_class->new;

    my %params = ( tmpl           => $template,
                   package_list   => [ '' ],
                   package_labels => [ 'Global Templates' ] );
    $self->_set_package_info( \%params );
    return $self->generate_content(
                    \%params,
                    { name => 'base_template::template_form' } );
}

sub update {
    my ( $self ) = @_;
    $log ||= get_logger( LOG_APP );

    $log->is_info &&
        $log->info( "Updating existing template" );
    CTX->response->return_url(
        OpenInteract2::URL->create_from_action( 'template' ) );

    my $request = CTX->request;
    my $package = $request->param( 'package_original' );
    my $name    = $request->param( 'name_original' );

    my $tmpl_class = CTX->lookup_class( 'template' );
    my $fq_name = $tmpl_class->create_name( $package, $name );
    my $template = eval { $tmpl_class->fetch( $fq_name ) };
    if ( $@ or ! $template ) {
        my $error = $@ || 'not found';
        $self->param_add(
            error_msg => "Failed to fetch template [$fq_name]: $error" );
        return $self->execute({ task => 'list' });
    }
    $template->package( $request->param( 'package' ) );
    $template->name( $request->param( 'name' ) );
    $template->set_contents( $request->param( 'contents' ) );
    eval { $template->save };
    if ( $@ ) {
        $self->param_add( error_msg => "Failed to save template: $@" );
        $self->param( template => $template );
        return $self->execute({ task => 'display_form' });
    }
    else {
        my $new_name = $template->create_name;
        $self->param_add( status_msg => "Template $new_name saved ok" );
        return $self->execute({ task => 'list' });
    }
}


sub add {
    my ( $self ) = @_;
    $log ||= get_logger( LOG_APP );

    $log->is_info &&
        $log->info( "Adding new template" );

    CTX->response->return_url(
        OpenInteract2::URL->create_from_action( 'template' ) );

    my $request = CTX->request;

    my $tmpl_class = CTX->lookup_class( 'template' );
    my $template = $tmpl_class->new;

    my $package = $request->param( 'package' );
    my $name    = $request->param( 'name' );

    $template->package( $package );
    $template->name( $name );
    $template->set_contents( $request->param( 'contents' ) );
    $self->param( template => $template );

    my $fq_name = $tmpl_class->create_name( $package, $name );
    my $existing_template = eval { $tmpl_class->fetch( $fq_name ) };
    if ( $existing_template ) {
        $self->param_add(
            error_msg => "Template [$fq_name] already exists, cannot create" );
        return $self->execute({ task => 'display_add' });
    }

    eval { $template->save };
    if ( $@ ) {
        $self->param_add( error_msg => "Failed to create template: $@" );
        return $self->execute({ task => 'display_add' });
    }
    else {
        $self->param_add( status_msg => "Template $fq_name saved ok" );
        return $self->execute({ task => 'list' });
    }
}


sub remove {
    my ( $self ) = @_;
    $log ||= get_logger( LOG_APP );

    $log->is_info &&
        $log->info( "Removing existing template" );

    my $request = CTX->request;
    my $template = $self->param( 'template' );
    my ( $fq_name );
    if ( $template ) {
        $fq_name = $template->create_name;
    }
    else {
        my $package = $request->param( 'package' );
        my $name    = $request->param( 'name' );
        my $tmpl_class = CTX->lookup_class( 'template' );
        $fq_name = $tmpl_class->create_name( $package, $name );
        $template = eval { $tmpl_class->fetch( $fq_name ) };
        if ( $@ ) {
            $self->param_add(
                error_msg => "Cannot fetch template [$fq_name]: $@" );
            return $self->execute({ task => 'list' });
        }
    }
    if ( $template ) {
        eval { $template->remove };
        if ( $@ ) {
            $self->param_add(
                error_msg => "Error removing template $fq_name: $@" );
        }
        else {
            $self->param_add(
                status_msg => "Template $fq_name removed ok" );
        }
    }
    else {
        $self->param_add(
            error_msg => "Template [$fq_name] does not seem to exist" );
    }
    return $self->execute({ task => 'list' });
}

1;
